ViewModelOwnerFeature class abstract interface

Base interface for external ViewModel features such as state manager integration.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

didChangeDependencies() → void
Represents State.didChangeDependencies.
didUpdateWidget() → void
Represents State.didUpdateWidget.
dispose() → void
Represents State.dispose.
init() → void
Represents State.initState.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited