meovm
library
Classes
AnimationMember
A member that allows the ViewModel to work with an AnimationController .
BuildableViewModelMember
Base class for all ViewModel members, on which it is allowed to build widgets.
CustomChangeNotifierMember <N extends ChangeNotifier >
A member that allows the ViewModel to work with an arbitrary
ChangeNotifier .
EditableTextMember
A member that allows the ViewModel to work with a TextEditingController .
FocusMember
A member that allows the ViewModel to work with a FocusNode .
ListMember <T >
A member that implements data storage and change of a list. For passing
data to widgets, it is recommended to use this class specifically:
ModalFlowMember <Result >
Member that allows controlling modal window from the ViewModel.
NavigationMember <T >
Member that allows controlling navigation from the ViewModel.
SetMember <T >
StateDependentVmOwnerFeature <S extends ViewModelDispatcherStateBase <ViewModelDispatcherBase <VM , Param > , VM , Param > , VM extends ViewModelLifecycle <Param > , Param extends ViewModelParameter ? >
Basic implementation of ViewModelOwnerFeature that provides access to
dispatcher's state.
StreamMember <T >
StreamMemberBase <T >
TabMember
A member that allows the ViewModel to work with a TabController .
UpdateNotifierMember <T >
The base class useful for all ViewModel members, the state of which is formed
based on data obtained from business state or other members.
ValueMember <T >
A member that implements data storage and change. For passing data to
widgets, it is recommended to use this class specifically:
ViewModel <Param extends ViewModelParameter ? >
Base class for ViewModel, providing lifecycle implementation,
member management, and their dependencies.
ViewModelDispatcher <VM extends ViewModelLifecycle <Param > , Param extends ViewModelParameter ? >
ViewModelDispatcherState <VM extends ViewModelLifecycle <Param > , Param extends ViewModelParameter ? >
ViewModelLifecycle <Param extends ViewModelParameter ? >
An interface for the lifecycle of the ViewModel, enabling its integration
with the State owner.
ViewModelMember
Base class for a ViewModel member implementing integration with
the State owner.
ViewModelMemberBase
An interface for the lifecycle of a ViewModel member, enabling its
integration with the ViewModel and the State owner.
ViewModelMemberFactory
ViewModel member factory providing a convenient way to add
members to the ViewModel with assigned identifiers (if no
explicit ViewModelMember.debugName is specified).
ViewModelOwner <Param extends ViewModelParameter ? >
An interface for the owner of the ViewModel, through which the ViewModel
and its members can interact with Flutter.
ViewModelOwnerFeature
Base interface for external ViewModel features such as state manager
integration.
ViewModelParameter
Base class for ViewModel configuration, that is passed to the ViewModel.
ViewModelParamProvider <Param >
ViewModelProvider <VM extends ViewModelLifecycle <ViewModelParameter ? > >
ViewModelScope